==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
var WebInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebInputDescriptionMetadata, _super);
    function WebInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputDescriptionMetadata.b = function (a) {
        if (WebInputDescriptionMetadata.a == null) {
            WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
        }
        if (a.g(WebInputDescriptionMetadata.a)) {
            return;
        }
        a.s(WebInputDescriptionMetadata.a);
        WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebInputDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Input");
        a.item("Value", "String");
        a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
        a.item("DisplayType@names", "Number;Email;Password;Search;Tel;Text;Url");
        a.item("Inputmode", "ExportedType:string:InputInputmode");
        a.item("Inputmode@names", "None;Email;Search;Tel;Url;Txt;Decimal;Numeric");
        a.item("Pattern", "String");
        a.item("Invalid", "Boolean");
        a.item("Minlength", "Number:double");
        a.item("Maxlength", "Number:double");
        a.item("Min", "String");
        a.item("Max", "String");
        a.item("Step", "Number:double");
        a.item("Autofocus", "Boolean");
        a.item("Autocomplete", "String");
        a.item("ChangeRef", "EventRef::change");
    };
    WebInputDescriptionMetadata.d = function (a) {
        WebInputDescriptionMetadata.b(a);
        a.u("WebInput", function () { return new WebInputDescription(); });
        a.t("WebInput", WebInputDescriptionMetadata.a);
    };
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
}(Base));
export { WebInputDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
var WebInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebInputDescriptionMetadata, _super);
    function WebInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputDescriptionMetadata.b = function (a) {
        if (WebInputDescriptionMetadata.a == null) {
            WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
        }
        if (a.j(WebInputDescriptionMetadata.a)) {
            return;
        }
        a.y(WebInputDescriptionMetadata.a);
        WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebInputDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Input");
        a.item("__tagNameWC", "String:igc-input");
        a.item("Value", "String");
        a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
        a.item("DisplayType@names", "Number;Email;Password;Search;Tel;Text;Url");
        a.item("Inputmode", "ExportedType:string:InputInputmode");
        a.item("Inputmode@names", "None;Email;Search;Tel;Url;Txt;Decimal;Numeric");
        a.item("Pattern", "String");
        a.item("Invalid", "Boolean");
        a.item("Minlength", "Number:double");
        a.item("Maxlength", "Number:double");
        a.item("Min", "String");
        a.item("Max", "String");
        a.item("Step", "Number:double");
        a.item("Autofocus", "Boolean");
        a.item("Autocomplete", "String");
        a.item("ChangeRef", "EventRef::change");
    };
    WebInputDescriptionMetadata.d = function (a) {
        WebInputDescriptionMetadata.b(a);
        a.aa("WebInput", function () { return new WebInputDescription(); });
        a.z("WebInput", WebInputDescriptionMetadata.a);
    };
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
}(Base));
export { WebInputDescriptionMetadata };
